==> datapark-facade-1.2.11-20180921.030532-1-sources.jar: com/bxm/datapark/facade/ticket/model/dto/AnalysisParamsDTO.java <==
package com.bxm.datapark.facade.ticket.model.dto;

import java.io.Serializable;

/**
 * 文 件 名 :
 * CopyRright (c) 2008-xxxx:
 * 文件编号：
 * 创 建 人： hxpeng
 * 日 期： 2018/8/9 17:00
 * 修 改 人：
 * 日 期：
 * 描 述： 广告券分析  通用参数DTO
 * 版 本 号： v1
 */
public class AnalysisParamsDTO implements Serializable {

    private static final long serialVersionUID = -6485046002908920924L;
    /**
     * 广告券ID, 媒体ID, 广告位ID
     */
    private String ticketId;
    private String mediaId;
    private String adPositionId;

    /**
     * 起始/结束时间
     */
    private String startTime;
    private String endTime;

    /**
     * 分页
     */
    private Integer pageNum;
    private Integer pageSize;

    /**
     * 排序类型 和 排序列
     */
    private String sortFieldName;
    private String sortType;

    /**
     * 媒体分析 分组类型
     */
    private String mediaGroupType;

    /**
     * 区域分析 分组类型
     */
    private String regionGroupType;

    public String getTicketId() {
        return ticketId;
    }

    public void setTicketId(String ticketId) {
        this.ticketId = ticketId;
    }

    public String getMediaId() {
        return mediaId;
    }

    public void setMediaId(String mediaId) {
        this.mediaId = mediaId;
    }

    public String getAdPositionId() {
        return adPositionId;
    }

    public void setAdPositionId(String adPositionId) {
        this.adPositionId = adPositionId;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getSortFieldName() {
        return sortFieldName;
    }

    public void setSortFieldName(String sortFieldName) {
        this.sortFieldName = sortFieldName;
    }

    public String getSortType() {
        return sortType;
    }

    public void setSortType(String sortType) {
        this.sortType = sortType;
    }

    public String getMediaGroupType() {
        return mediaGroupType;
    }

    public void setMediaGroupType(String mediaGroupType) {
        this.mediaGroupType = mediaGroupType;
    }

    public String getRegionGroupType() {
        return regionGroupType;
    }

    public void setRegionGroupType(String regionGroupType) {
        this.regionGroupType = regionGroupType;
    }
}

==> datapark-facade-2.0.0-sources.jar: com/bxm/datapark/facade/ticket/model/dto/AnalysisParamsDTO.java <==
package com.bxm.datapark.facade.ticket.model.dto;

import java.io.Serializable;
import java.util.List;

/**
 * 文 件 名 :
 * CopyRright (c) 2008-xxxx:
 * 文件编号：
 * 创 建 人： hxpeng
 * 日 期： 2018/8/9 17:00
 * 修 改 人：
 * 日 期：
 * 描 述： 广告券分析  通用参数DTO
 * 版 本 号： v1
 */
public class AnalysisParamsDTO implements Serializable {

    private static final long serialVersionUID = -6485046002908920924L;
    /**
     * 广告券ID, 媒体ID, 广告位ID
     */
    private String ticketId;
    private String mediaId;
    private String adPositionId;

    /**
     * 起始/结束时间
     */
    private String startTime;
    private String endTime;

    /**
     * 分页
     */
    private Integer pageNum;
    private Integer pageSize;

    /**
     * 排序类型 和 排序列
     */
    private String sortFieldName;
    private String sortType;

    /**
     * 媒体分析 分组类型
     */
    private String mediaGroupType;

    /**
     * 区域分析 分组类型
     */
    private String regionGroupType;
    
    /**
     * appKey集合
     */
    private List<String> appKeyList;
    
    /**
     * 广告位id集合
     */
    private List<String> positionIdList;


    public String getTicketId() {
        return ticketId;
    }

    public void setTicketId(String ticketId) {
        this.ticketId = ticketId;
    }

    public String getMediaId() {
        return mediaId;
    }

    public void setMediaId(String mediaId) {
        this.mediaId = mediaId;
    }

    public String getAdPositionId() {
        return adPositionId;
    }

    public void setAdPositionId(String adPositionId) {
        this.adPositionId = adPositionId;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getSortFieldName() {
        return sortFieldName;
    }

    public void setSortFieldName(String sortFieldName) {
        this.sortFieldName = sortFieldName;
    }

    public String getSortType() {
        return sortType;
    }

    public void setSortType(String sortType) {
        this.sortType = sortType;
    }

    public String getMediaGroupType() {
        return mediaGroupType;
    }

    public void setMediaGroupType(String mediaGroupType) {
        this.mediaGroupType = mediaGroupType;
    }

    public String getRegionGroupType() {
        return regionGroupType;
    }

    public void setRegionGroupType(String regionGroupType) {
        this.regionGroupType = regionGroupType;
    }

    public List<String> getAppKeyList() {
        return appKeyList;
    }

    public void setAppKeyList(List<String> appKeyList) {
        this.appKeyList = appKeyList;
    }

    public List<String> getPositionIdList() {
        return positionIdList;
    }

    public void setPositionIdList(List<String> positionIdList) {
        this.positionIdList = positionIdList;
    }
}
